@@ -8,10 +8,10 @@ are intended for the command.
 
 Full help displayed with %prog --help'''
 
-VERSION_NUMBER = '0.13'
+VERSION_NUMBER = '1.0'
 
 VERSION_TEXT = '%%prog version %s' % VERSION_NUMBER
 
-BUILTIN_BLACK_LIST = ['.hg', '.git', '.bzr', '.svn', '#*', '.#*', '*.swp']
+BUILTIN_BLACK_LIST = ['.hg', '.git', '.bzr', '.svn', 'CVS', '*~', '#*', '.#*', '*.swp', '*.pyc', '*.pyo']
 
 WIDTH = 80
